@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013-2019, Camptocamp SA
+# Copyright (c) 2013-2020, Camptocamp SA
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -28,59 +28,63 @@
 # either expressed or implied, of the FreeBSD Project.
 
 
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+from email.utils import formatdate
 import logging
 import smtplib
-from typing import Dict, Any, List, cast
 from socket import gaierror
-from email.mime.text import MIMEText
-from email.mime.multipart import MIMEMultipart
-from email.utils import formatdate
-from pyramid.httpexceptions import HTTPInternalServerError
+from typing import Any, Dict, List, cast
+
+try:
+    from pyramid.httpexceptions import HTTPInternalServerError
+except ModuleNotFoundError:
+
+    class HTTPInternalServerError(BaseException):  # type: ignore
+        pass
 
 
 LOG = logging.getLogger(__name__)
 
 
 def send_email_config(
-    settings: Dict[str, Any],
-    email_config_name: str,
-    email: str, **kwargs: Dict[str, Any]
+    settings: Dict[str, Any], email_config_name: str, email: str, **kwargs: Dict[str, Any]
 ) -> None:  # pragma: no cover
-    smtp_config = settings['smtp']
+    smtp_config = settings["smtp"]
     email_config = cast(Dict[str, str], settings[email_config_name])
 
     try:
         send_email(
-            email_config['email_from'], [email],
-            email_config['email_body'].format(**kwargs),
-            email_config['email_subject'],
+            email_config["email_from"],
+            [email],
+            email_config["email_body"].format(**kwargs),
+            email_config["email_subject"],
             smtp_config,
         )
     except gaierror:
-        LOG.error('Unable to send the email.', exc_info=True)
-        raise HTTPInternalServerError('See server logs for details')
+        LOG.error("Unable to send the email.", exc_info=True)
+        raise HTTPInternalServerError("See server logs for details")
 
 
 def send_email(
-    from_addr: str, to_addrs: List[str], body: str, subject: str,
-    smtp_config: Dict[str, str]
+    from_addr: str, to_addrs: List[str], body: str, subject: str, smtp_config: Dict[str, str]
 ) -> None:  # pragma: no cover
     msg = MIMEMultipart()
-    msg['From'] = from_addr
-    msg['To'] = ', '.join(to_addrs)
-    msg['Date'] = formatdate(localtime=True)
-    msg['Subject'] = subject
-    msg.attach(MIMEText(body, 'plain', 'utf-8'))
+    msg["From"] = from_addr
+    msg["To"] = ", ".join(to_addrs)
+    msg["Date"] = formatdate(localtime=True)
+    msg["Subject"] = subject
+    msg.attach(MIMEText(body, "plain", "utf-8"))
 
     # Connect to server
-    if smtp_config.get('ssl', False):
-        smtp = smtplib.SMTP_SSL(smtp_config['host'])  # type: smtplib.SMTP
+    if smtp_config.get("ssl", False):
+        smtp: smtplib.SMTP = smtplib.SMTP_SSL(smtp_config["host"])
     else:
-        smtp = smtplib.SMTP(smtp_config['host'])
-    if smtp_config.get('starttls', False):
+        smtp = smtplib.SMTP(smtp_config["host"])
+    if smtp_config.get("starttls", False):
         smtp.starttls()
-    if smtp_config.get('user', False):
-        smtp.login(smtp_config['user'], smtp_config['password'])
+    if smtp_config.get("user", False):
+        smtp.login(smtp_config["user"], smtp_config["password"])
 
     smtp.sendmail(from_addr, to_addrs, msg.as_string())
     smtp.close()
